==> zscaler_sdk_python-1.0.2.tar.gz: zscaler_sdk_python-1.0.2/zscaler/zia/models/remoteassistance.py <==
# flake8: noqa
"""
Copyright (c) 2023, Zscaler Inc.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted, provided that the above
copyright notice and this permission notice appear in all copies.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
"""

from zscaler.oneapi_object import ZscalerObject


class RemoteAssistance(ZscalerObject):
    """
    A class for RemoteAssistance objects.
    """

    def __init__(self, config=None):
        """
        Initialize the RemoteAssistance model based on API response.

        Args:
            config (dict): A dictionary representing the configuration.
        """
        super().__init__(config)

        if config:
            self.view_only_until = config["viewOnlyUntil"] if "viewOnlyUntil" in config else None
            self.full_access_until = config["fullAccessUntil"] if "fullAccessUntil" in config else None
            self.username_obfuscated = config["usernameObfuscated"] if "usernameObfuscated" in config else False
            self.device_info_obfuscate = config["deviceInfoObfuscate"] if "deviceInfoObfuscate" in config else False
        else:
            self.view_only_until = None
            self.full_access_until = None
            self.username_obfuscated = False
            self.device_info_obfuscate = False

    def request_format(self):
        """
        Return the object as a dictionary in the format expected for API requests.
        """
        parent_req_format = super().request_format()
        current_obj_format = {
            "viewOnlyUntil": self.view_only_until,
            "fullAccessUntil": self.full_access_until,
            "usernameObfuscated": self.username_obfuscated,
            "deviceInfoObfuscate": self.device_info_obfuscate,
        }
        parent_req_format.update(current_obj_format)
        return parent_req_format

==> zscaler_sdk_python-1.9.2.tar.gz: zscaler_sdk_python-1.9.2/zscaler/zia/models/remoteassistance.py <==
# flake8: noqa
"""
Copyright (c) 2023, Zscaler Inc.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted, provided that the above
copyright notice and this permission notice appear in all copies.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
"""

from typing import Dict, List, Optional, Any, Union
from zscaler.oneapi_object import ZscalerObject


class RemoteAssistance(ZscalerObject):
    """
    A class for RemoteAssistance objects.
    """

    def __init__(self, config: Optional[Dict[str, Any]] = None) -> None:
        """
        Initialize the RemoteAssistance model based on API response.

        Args:
            config (dict): A dictionary representing the configuration.
        """
        super().__init__(config)

        if config:
            self.view_only_until = config["viewOnlyUntil"] if "viewOnlyUntil" in config else None
            self.full_access_until = config["fullAccessUntil"] if "fullAccessUntil" in config else None
            self.username_obfuscated = config["usernameObfuscated"] if "usernameObfuscated" in config else False
            self.device_info_obfuscate = config["deviceInfoObfuscate"] if "deviceInfoObfuscate" in config else False
        else:
            self.view_only_until = None
            self.full_access_until = None
            self.username_obfuscated = False
            self.device_info_obfuscate = False

    def request_format(self) -> Dict[str, Any]:
        """
        Return the object as a dictionary in the format expected for API requests.
        """
        parent_req_format = super().request_format()
        current_obj_format = {
            "viewOnlyUntil": self.view_only_until,
            "fullAccessUntil": self.full_access_until,
            "usernameObfuscated": self.username_obfuscated,
            "deviceInfoObfuscate": self.device_info_obfuscate,
        }
        parent_req_format.update(current_obj_format)
        return parent_req_format
